@@ -1,7 +1,7 @@
-from ...._schemas import ResponseBase
+from ...._schemas import ApiDataModel
 
 
-class GetLocationResponse(ResponseBase):
+class GetLocationResponse(ApiDataModel):
     city: str
     city_lat_long: str
     country_code: str
