@@ -1,8 +1,8 @@
 from pydantic import ConfigDict
-from ...._schemas import ResponseBase
+from ...._schemas import ApiDataModel
 
 
-class GetWebTimerResponse(ResponseBase):
+class GetWebTimerResponse(ApiDataModel):
     # The web timer payload contains various fields; allow passthrough.
     model_config = ConfigDict(extra="allow")
 
